import Foundation

enum CardRarity: String, Codable, CaseIterable {
    case normal = "normal"
    case rare = "rare"
    case superRare = "super_rare"
    case kira = "kira"
    case unique = "unique"
    
    var displayName: String {
        switch self {
        case .normal: return "ノーマル"
        case .rare: return "レア"
        case .superRare: return "スーパーレア"
        case .kira: return "キラ"
        case .unique: return "ユニーク"
        }
    }
    
    var gradientColors: [String] {
        switch self {
        case .normal: return ["666666", "333333"]
        case .rare: return ["4a90e2", "16213e"]
        case .superRare: return ["9c27b0", "0f0c29"]
        case .kira: return ["ffd700", "414345"]
        case .unique: return ["ff00ff", "1a0033"]
        }
    }
}

struct Card: Identifiable, Codable {
    let id: Int
    let cp: Int
    let status: CardRarity
    let skill: String?
    let ownerDid: String
    let obtainedAt: Date
    let isUnique: Bool
    let uniqueId: String?
    
    private enum CodingKeys: String, CodingKey {
        case id
        case cp
        case status
        case skill
        case ownerDid = "owner_did"
        case obtainedAt = "obtained_at"
        case isUnique = "is_unique"
        case uniqueId = "unique_id"
    }
}

struct CardDrawResult: Codable {
    let card: Card
    let isNew: Bool
    let animationType: String
    
    private enum CodingKeys: String, CodingKey {
        case card
        case isNew = "is_new"
        case animationType = "animation_type"
    }
}

struct DrawStatus: Codable {
    let canDraw: Bool
    let nextDrawTime: Date?
    let drawLimitDays: Int
    
    private enum CodingKeys: String, CodingKey {
        case canDraw = "can_draw"
        case nextDrawTime = "next_draw_time"
        case drawLimitDays = "draw_limit_days"
    }
}

// Card master data
struct CardInfo {
    let id: Int
    let name: String
    let color: String
    let description: String
    
    static let all: [Int: CardInfo] = [
        0: CardInfo(id: 0, name: "アイ", color: "fff700", description: "世界の最小単位"),
        1: CardInfo(id: 1, name: "夢幻", color: "b19cd9", description: "意識が物質を作る"),
        2: CardInfo(id: 2, name: "光彩", color: "ffd700", description: "存在は光に向かう"),
        3: CardInfo(id: 3, name: "中性子", color: "cacfd2", description: "中性子"),
        4: CardInfo(id: 4, name: "太陽", color: "ff6b35", description: "太陽"),
        5: CardInfo(id: 5, name: "夜空", color: "1a1a2e", description: "夜空"),
        6: CardInfo(id: 6, name: "雪", color: "e3f2fd", description: "雪"),
        7: CardInfo(id: 7, name: "雷", color: "ffd93d", description: "雷"),
        8: CardInfo(id: 8, name: "超究", color: "6c5ce7", description: "超究"),
        9: CardInfo(id: 9, name: "剣", color: "a8e6cf", description: "剣"),
        10: CardInfo(id: 10, name: "破壊", color: "ff4757", description: "破壊"),
        11: CardInfo(id: 11, name: "地球", color: "4834d4", description: "地球"),
        12: CardInfo(id: 12, name: "天の川", color: "9c88ff", description: "天の川"),
        13: CardInfo(id: 13, name: "創造", color: "00d2d3", description: "創造"),
        14: CardInfo(id: 14, name: "超新星", color: "ff9ff3", description: "超新星"),
        15: CardInfo(id: 15, name: "世界", color: "54a0ff", description: "存在と世界は同じもの")
    ]
}